@@ -2,10 +2,10 @@ assimilation <-
 function(plants, # marked point pattern (class ppp)
          pixsize=0.2, # resolution (pixel size)
          resource=1, # resource map
-         influence=gnomon.inf, # influence function
-         infpar=list(a=1, b=4, smark=1), # influence function parameter(s)
+         influence=gnomon_inf, # influence function
+         infpar=NULL, # influence function parameter(s)
          asym=Inf, # asymmetry parameter
-         efficiency=flat.eff, # efficiency function
+         efficiency=flat_eff, # efficiency function
          effpar=NULL, # efficiency function parameter(s)
          plot=TRUE, # plot influences map?
          afree=FALSE, # include free-growing assimilation in output?         
@@ -15,7 +15,7 @@ function(plants, # marked point pattern (class ppp)
     # Resource pixel image
     resource <- as.im(resource, as.mask(plants, eps=pixsize))
     resmatrix <- as.matrix(resource)
-    # This is dangerous, spatstat warns about possible implementation changes:
+    # Dangerous? spatstat warns about future implementation changes:
     xcol <- resource$xcol
     yrow <- resource$yrow
     pixarea <- resource$xstep * resource$ystep
@@ -24,8 +24,13 @@ function(plants, # marked point pattern (class ppp)
     yplant <- coords(plants)$y
     marks <- as.data.frame(marks(plants))
     # First pass, acccumulate partition function denominator
-    infi <- function(y, x) influence(dx = x - xplant[i], dy = y - yplant[i],
-        marks = marks[i, ], par = infpar)
+    if(is.null(infpar)) { # use the influence default parameters, if any
+        infi <- function(y, x) pmax(0, influence(dx = x - xplant[i],
+            dy = y - yplant[i], marks = marks[i, ]))
+    } else { # pass the given influence function parameters
+        infi <- function(y, x) pmax(0, influence(dx = x - xplant[i],
+            dy = y - yplant[i], marks = marks[i, ], par = infpar))
+    }
     denom <- 0 * resmatrix
     for(i in 1:npoints(plants)) {
         phi <- outer(yrow, xcol, infi)
@@ -36,14 +41,19 @@ function(plants, # marked point pattern (class ppp)
     }
     if(plot) plot(as.im(denom, resource), main=NULL)
     # Second pass, get assimilation index for each plant
-    effi <- function(y, x) efficiency(dx = x - xplant[i], dy = y - yplant[i],
-        marks = marks[i, ], par = effpar)
+    if(is.null(effpar)) {
+        effi <- function(y, x) pmax(0, efficiency(dx = x - xplant[i],
+            dy = y - yplant[i], marks = marks[i, ]))
+    } else {
+        effi <- function(y, x) pmax(0, efficiency(dx = x - xplant[i],
+            dy = y - yplant[i], marks = marks[i, ], par = effpar))
+    }
     for(i in 1:npoints(plants)) {
         phi <- outer(yrow, xcol, infi)
         if(is.infinite(asym)) part <- (phi >= denom) * (phi > 0)
         else if(asym == 1) part <- phi / (denom + (denom == 0))
         else if(asym > 0) part <- phi^asym / (denom + (denom == 0))
-                # avoid division by 0
+                                            # avoid division by 0
         else part <- (phi > 0) / (denom + (denom == 0)) # asym == 0
         eff <- outer(yrow, xcol, effi)
         assim <- eff * part * resmatrix
